@@ -147,8 +147,8 @@ class GenerateCitationNet():
             inyear = self.getPubDate(data)
             self.mainNode = (
                 doi,
-                data['title'],
-                data['is-referenced-by-count'],
+                data['title'][0],
+                data['is-referenced-by-count'][0],
                 inyear
             )
             return 'Done'
@@ -158,7 +158,7 @@ class GenerateCitationNet():
     def getCitationsDF(self, doi):
         flDict = {
             'rows': 1,
-            'fl': 'DOI,reference-count,is-referenced-by-count,author.family,title,published-print.date-parts,issued.date-parts,published-online.date-parts,container-title,reference.DOI,reference.unstructured'
+            'fl': 'DOI,reference-count,is-referenced-by-count,author.family,title,published-print.date-parts,issued.date-parts,published-online.date-parts,container-title,reference.DOI,reference.unstructured'  # noqa: E501
             }
         start_time = time.time()
         search = self.solr.search(f'DOI:"{doi}"', **flDict)
@@ -239,7 +239,10 @@ class GenerateCitationNet():
                         pass
                 if debug:
                     print(outputDict)
-                dfOut = pd.DataFrame([outputDict]).transpose()
+                if all(type(value) == str for value in outputDict.values()):
+                    dfOut = pd.DataFrame([outputDict]).transpose()
+                else:
+                    dfOut = pd.DataFrame(outputDict).transpose()
                 dfOut = dfOut.reset_index().rename(
                     columns={'index': 'targetFull'}
                     )
@@ -430,7 +433,6 @@ class GenerateCitationNet():
                 missingYears = dfRes[(dfRes.sourceYear == '') | (dfRes.targetYear == '')].shape[0]
                 if debug:
                     print(f'Total runtime {(time.time() - start_time)}')
-                    # # TODO: For some edge cases there is no column sourceYear. How is that possible? Check DOI: 10.1007/bf00626622
                     print(f'Found no year for {missingYears} entries, changed to main DOI year.')
                 dfRes.targetYear.replace(
                     r'^\s*$', self.mainNode[3], regex=True, inplace=True
@@ -440,5 +442,16 @@ class GenerateCitationNet():
                     )
             else:
                 return
+        colDefault = [
+            'sourceDOI', 'sourcetitleStr', 'sourceis_ref_byCount',
+            'sourceYear', 'targetDOI', 'targettitleStr',
+            'targetis_ref_byCount', 'targetYear'
+            ]
+        missingCols = [x for x in colDefault if x not in dfRes.columns]
+        if missingCols:
+            if debug:
+                print(f'Found columns missing: {missingCols}, adding empty.')
+            for newcol in missingCols:
+                dfRef.insert(0, newcol, '')
         self.resultDF = dfRes
         return dfRes
